@@ -5,7 +5,7 @@ use Log::Message private => 0;;
 
 BEGIN { 
     use vars qw[$VERSION]; 
-    $VERSION = "-1";
+    $VERSION = 0.08; 
 }
         
 
@@ -13,7 +13,7 @@ BEGIN {
 
 =head1 NAME
 
-Log::Message::Simple
+Log::Message::Simple - Simplified interface to Log::Message
 
 =head1 SYNOPSIS
 
@@ -139,31 +139,31 @@ Exported by default, or using the C<:STD> tag.
 
 =head2 carp();
 
-Provides functionality equal to C<Carp::carp()>, whilst still logging
+Provides functionality equal to C<Carp::carp()> while still logging
 to the stack.
 
-Exported by by using the C<:CARP> tag.
+Exported by using the C<:CARP> tag.
 
 =head2 croak();
 
-Provides functionality equal to C<Carp::croak()>, whilst still logging
+Provides functionality equal to C<Carp::croak()> while still logging
 to the stack.
 
-Exported by by using the C<:CARP> tag.
+Exported by using the C<:CARP> tag.
 
 =head2 confess();
 
-Provides functionality equal to C<Carp::confess()>, whilst still logging
+Provides functionality equal to C<Carp::confess()> while still logging
 to the stack.
 
-Exported by by using the C<:CARP> tag.
+Exported by using the C<:CARP> tag.
 
 =head2 cluck();
 
-Provides functionality equal to C<Carp::cluck()>, whilst still logging
+Provides functionality equal to C<Carp::cluck()> while still logging
 to the stack.
 
-Exported by by using the C<:CARP> tag.
+Exported by using the C<:CARP> tag.
 
 =head1 CLASS METHODS
 
@@ -269,6 +269,8 @@ If this option is set to C<true>, every call to C<error()> will
 generate a stacktrace using C<Carp::shortmess()>.
 Defaults to C<false>
 
+=back
+
 =cut
 
 BEGIN {
